==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/km-KH/admin/models/message.php <==
<?php

return array(

    'deleted' => 'គំរូទ្រព្យសកម្មដែលបានលុប',
    'does_not_exist' => 'ម៉ូដែលមិនមានទេ។',
    'no_association' => 'ព្រមាន! គំរូទ្រព្យសកម្មសម្រាប់ធាតុនេះមិនត្រឹមត្រូវ ឬបាត់!',
    'no_association_fix' => 'វា​នឹង​បំបែក​រឿង​ក្នុង​វិធី​ចម្លែក និង​គួរ​ឲ្យ​រន្ធត់។ កែសម្រួលទ្រព្យសកម្មនេះឥឡូវនេះ ដើម្បីចាត់ឱ្យវាជាគំរូមួយ។',
    'assoc_users'	 => 'បច្ចុប្បន្ន ម៉ូដែលនេះត្រូវបានភ្ជាប់ជាមួយទ្រព្យសកម្មមួយ ឬច្រើន ហើយមិនអាចលុបបានទេ។ សូមលុបទ្រព្យសម្បត្តិ ហើយបន្ទាប់មកព្យាយាមលុបម្តងទៀត។ ',
    'invalid_category_type' => 'The category must be an asset category.',

    'create' => array(
        'error'   => 'គំរូមិនត្រូវបានបង្កើតទេ សូមព្យាយាមម្តងទៀត។',
        'success' => 'គំរូត្រូវបានបង្កើតដោយជោគជ័យ។',
        'duplicate_set' => 'គំរូទ្រព្យសកម្មដែលមានឈ្មោះ ក្រុមហ៊ុនផលិត និងលេខម៉ូដែលនោះមានរួចហើយ។',
    ),

    'update' => array(
        'error'   => 'ម៉ូដែលមិនត្រូវបានអាប់ដេតទេ សូមព្យាយាមម្តងទៀត',
        'success' => 'ម៉ូដែលបានធ្វើបច្ចុប្បន្នភាពដោយជោគជ័យ។',
    ),

    'delete' => array(
        'confirm'   => 'តើអ្នកប្រាកដថាចង់លុបគំរូទ្រព្យសកម្មនេះទេ?',
        'error'   => 'មាន​បញ្ហា​ក្នុង​ការ​លុប​ម៉ូដែល។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'success' => 'គំរូត្រូវបានលុបដោយជោគជ័យ។'
    ),

    'restore' => array(
        'error'   		=> 'ម៉ូដែលមិនត្រូវបានស្ដារឡើងវិញទេ សូមព្យាយាមម្តងទៀត',
        'success' 		=> 'ម៉ូដែលត្រូវបានស្ដារឡើងវិញដោយជោគជ័យ។'
    ),

    'bulkedit' => array(
        'error'   		=> 'គ្មាន fields ត្រូវបានផ្លាស់ប្តូរ ដូច្នេះគ្មានអ្វីត្រូវបានធ្វើបច្ចុប្បន្នភាពទេ។',
        'success' 		=> 'បានធ្វើបច្ចុប្បន្នភាពគំរូដោយជោគជ័យ។ |:model_count model បានធ្វើបច្ចុប្បន្នភាពដោយជោគជ័យ។',
        'warn'          => 'You are about to update the properties of the following model:|You are about to edit the properties of the following :model_count models:',

    ),

    'bulkdelete' => array(
        'error'   		    => 'គ្មាន​ម៉ូដែល​ត្រូវ​បាន​ជ្រើសរើស ដូច្នេះ​មិន​មាន​អ្វី​ត្រូវ​បាន​លុប។',
        'success' 		    => 'បានលុបម៉ូដែល!|:success_count model ត្រូវបានលុប!',
        'success_partial' 	=> ':success_count model(s) ត្រូវបានលុប ទោះយ៉ាងណាក៏ដោយ :fail_count មិនអាចលុបបានទេ ដោយសារពួកគេនៅតែមានទ្រព្យសកម្មដែលពាក់ព័ន្ធជាមួយពួកគេ។'
    ),

);

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/km-KH/admin/models/message.php <==
<?php

return array(

    'deleted' => 'គំរូទ្រព្យសកម្មដែលបានលុប',
    'does_not_exist' => 'ម៉ូដែលមិនមានទេ។',
    'no_association' => 'ព្រមាន! គំរូទ្រព្យសកម្មសម្រាប់ធាតុនេះមិនត្រឹមត្រូវ ឬបាត់!',
    'no_association_fix' => 'វា​នឹង​បំបែក​រឿង​ក្នុង​វិធី​ចម្លែក និង​គួរ​ឲ្យ​រន្ធត់។ កែសម្រួលទ្រព្យសកម្មនេះឥឡូវនេះ ដើម្បីចាត់ឱ្យវាជាគំរូមួយ។',
    'assoc_users'	 => 'បច្ចុប្បន្ន ម៉ូដែលនេះត្រូវបានភ្ជាប់ជាមួយទ្រព្យសកម្មមួយ ឬច្រើន ហើយមិនអាចលុបបានទេ។ សូមលុបទ្រព្យសម្បត្តិ ហើយបន្ទាប់មកព្យាយាមលុបម្តងទៀត។ ',
    'invalid_category_type' => 'This category must be an asset category.',

    'create' => array(
        'error'   => 'គំរូមិនត្រូវបានបង្កើតទេ សូមព្យាយាមម្តងទៀត។',
        'success' => 'គំរូត្រូវបានបង្កើតដោយជោគជ័យ។',
        'duplicate_set' => 'គំរូទ្រព្យសកម្មដែលមានឈ្មោះ ក្រុមហ៊ុនផលិត និងលេខម៉ូដែលនោះមានរួចហើយ។',
    ),

    'update' => array(
        'error'   => 'ម៉ូដែលមិនត្រូវបានអាប់ដេតទេ សូមព្យាយាមម្តងទៀត',
        'success' => 'ម៉ូដែលបានធ្វើបច្ចុប្បន្នភាពដោយជោគជ័យ។',
    ),

    'delete' => array(
        'confirm'   => 'តើអ្នកប្រាកដថាចង់លុបគំរូទ្រព្យសកម្មនេះទេ?',
        'error'   => 'មាន​បញ្ហា​ក្នុង​ការ​លុប​ម៉ូដែល។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'success' => 'គំរូត្រូវបានលុបដោយជោគជ័យ។'
    ),

    'restore' => array(
        'error'   		=> 'ម៉ូដែលមិនត្រូវបានស្ដារឡើងវិញទេ សូមព្យាយាមម្តងទៀត',
        'success' 		=> 'ម៉ូដែលត្រូវបានស្ដារឡើងវិញដោយជោគជ័យ។'
    ),

    'bulkedit' => array(
        'error'   		=> 'គ្មាន fields ត្រូវបានផ្លាស់ប្តូរ ដូច្នេះគ្មានអ្វីត្រូវបានធ្វើបច្ចុប្បន្នភាពទេ។',
        'success' 		=> 'បានធ្វើបច្ចុប្បន្នភាពគំរូដោយជោគជ័យ។ |:model_count model បានធ្វើបច្ចុប្បន្នភាពដោយជោគជ័យ។',
        'warn'          => 'You are about to update the properties of the following model:|You are about to edit the properties of the following :model_count models:',

    ),

    'bulkdelete' => array(
        'error'   		    => 'គ្មាន​ម៉ូដែល​ត្រូវ​បាន​ជ្រើសរើស ដូច្នេះ​មិន​មាន​អ្វី​ត្រូវ​បាន​លុប។',
        'success' 		    => 'បានលុបម៉ូដែល!|:success_count model ត្រូវបានលុប!',
        'success_partial' 	=> ':success_count model(s) ត្រូវបានលុប ទោះយ៉ាងណាក៏ដោយ :fail_count មិនអាចលុបបានទេ ដោយសារពួកគេនៅតែមានទ្រព្យសកម្មដែលពាក់ព័ន្ធជាមួយពួកគេ។'
    ),

);
